==> opensaml-saml-impl-3.3.1-sources.jar: org/opensaml/saml/saml2/core/impl/AssertionURIRefBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */

package org.opensaml.saml.saml2.core.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.saml2.core.AssertionURIRef;

/**
 * Builder for {@link org.opensaml.saml.saml2.core.impl.AssertionURIRefImpl} objects.
 */
public class AssertionURIRefBuilder extends AbstractSAMLObjectBuilder<AssertionURIRef> {

    /** Constructor. */
    public AssertionURIRefBuilder() {

    }

    /** {@inheritDoc} */
    public AssertionURIRef buildObject() {
        return buildObject(SAMLConstants.SAML20_NS, AssertionURIRef.DEFAULT_ELEMENT_LOCAL_NAME,
                SAMLConstants.SAML20_PREFIX);
    }

    /** {@inheritDoc} */
    public AssertionURIRef buildObject(String namespaceURI, String localName, String namespacePrefix) {
        return new AssertionURIRefImpl(namespaceURI, localName, namespacePrefix);
    }
}

==> opensaml-saml-impl-3.4.6-sources.jar: org/opensaml/saml/saml2/core/impl/AssertionURIRefBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */

package org.opensaml.saml.saml2.core.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.saml.common.xml.SAMLConstants;
import org.opensaml.saml.saml2.core.AssertionURIRef;

/**
 * Builder for {@link org.opensaml.saml.saml2.core.impl.AssertionURIRefImpl} objects.
 */
public class AssertionURIRefBuilder extends AbstractSAMLObjectBuilder<AssertionURIRef> {

    /** Constructor. */
    public AssertionURIRefBuilder() {

    }

    /** {@inheritDoc} */
    public AssertionURIRef buildObject() {
        return buildObject(SAMLConstants.SAML20_NS, AssertionURIRef.DEFAULT_ELEMENT_LOCAL_NAME,
                SAMLConstants.SAML20_PREFIX);
    }

    /** {@inheritDoc} */
    public AssertionURIRef buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new AssertionURIRefImpl(namespaceURI, localName, namespacePrefix);
    }
}
